TransactionChangesBuilder

Struct TransactionChangesBuilder 

pub struct TransactionChangesBuilder { /* private fields */ }
Builds TransactionChanges struct

Ensures uniqueness for contract addresses and component ids.

Implementations

Source

impl TransactionChangesBuilder

pub fn new(tx: &Transaction) -> Self

Initialize a new builder for a transaction.

pub fn add_contract_changes(&mut self, change: &InterimContractChange)

Register a new contract change.

Will prioritize the new change over any already present one.

pub fn changed_contracts(&self) -> impl Iterator<Item = &[u8]>

Unique contract/account addresses that have been changed so far.

pub fn mark_component_as_updated(&mut self, component_id: &str)

Marks a component as updated.

If the protocol does not follow a 1:1 logic between components and contracts. Components can be manually marked as updated using this method.

pub fn change_component_pause_state(&mut self, component_id: &str, paused: bool)

Marks a protocol component as paused or unpaused.

Enables/disables swapping on the protocol component.

Parameters
  • component_id - The unique identifier of the protocol component
  • paused - true to pause the component, false to unpause it
pub fn add_entity_change(&mut self, change: &EntityChanges)

Registers a new entity change.

Will prioritize the new change over any already present one.

pub fn add_protocol_component(&mut self, component: &ProtocolComponent)

Adds a new protocol component.

Note

This method is a noop, in case the component is already present. Since components are assumed to be immutable.

pub fn add_balance_change(&mut self, change: &BalanceChange)

Updates a components balances

Overwrites any previous balance changes of the component if present.

pub fn add_entrypoint(&mut self, entrypoint: &EntryPoint)

Adds a new entrypoint to the transaction. It adds to the set of already existing entrypoints.

pub fn add_entrypoint_params(&mut self, entrypoint: &EntryPointParams)

pub fn build(self) -> Option<TransactionChanges>